@@ -25,9 +25,9 @@ function build_dpdk()
         pushd dpdk-src
     fi
 
-    # Switching to 'default' machine to make the dpdk cache usable on
+    # Switching to 'generic' platform to make the dpdk cache usable on
     # different CPUs. We can't be sure that all CI machines are exactly same.
-    DPDK_OPTS="$DPDK_OPTS -Dmachine=default"
+    DPDK_OPTS="$DPDK_OPTS -Dplatform=generic"
 
     # Disable building DPDK unit tests. Not needed for OVS build or tests.
     DPDK_OPTS="$DPDK_OPTS -Dtests=false"
@@ -40,7 +40,7 @@ function build_dpdk()
     # any DPDK driver.
     # check-dpdk unit tests requires testpmd and some net/ driver.
     DPDK_OPTS="$DPDK_OPTS -Denable_apps=test-pmd"
-    enable_drivers="net/null,net/af_xdp,net/tap,net/virtio"
+    enable_drivers="net/null,net/af_xdp,net/tap,net/virtio,net/pcap"
     DPDK_OPTS="$DPDK_OPTS -Denable_drivers=$enable_drivers"
     # OVS depends on the vhost library (and its dependencies).
     # net/tap depends on the gso library.
@@ -49,7 +49,7 @@ function build_dpdk()
     # Install DPDK using prefix.
     DPDK_OPTS="$DPDK_OPTS --prefix=$DPDK_INSTALL_DIR"
 
-    meson $DPDK_OPTS build
+    meson setup $DPDK_OPTS build
     ninja -C build
     ninja -C build install
     popd
