@@ -831,10 +831,14 @@ check_condition(const struct ovsdb_idl_table_class *table,
         } else {
             struct ovsdb_datum a;
 
-            ovsdb_datum_init_empty(&a);
             if (found) {
                 a.n = 1;
                 a.keys = &have_datum->values[idx];
+                a.values = NULL;
+            } else {
+                a.n = 0;
+                a.keys = NULL;
+                a.values = NULL;
             }
 
             retval = evaluate_relop(&a, &b, &type, operator);
@@ -1156,8 +1160,8 @@ list_record(const struct ovsdb_idl_row *row,
 
             atom.uuid = row->uuid;
 
-            ovsdb_datum_init_empty(&datum);
             datum.keys = &atom;
+            datum.values = NULL;
             datum.n = 1;
 
             cell->json = ovsdb_datum_to_json(&datum, &ovsdb_type_uuid);
@@ -2652,6 +2656,7 @@ ctl_context_init(struct ctl_context *ctx, struct ctl_command *command,
                  struct ovsdb_symbol_table *symtab,
                  void (*invalidate_cache_cb)(struct ctl_context *))
 {
+    ds_init(&ctx->output);
     if (command) {
         ctl_context_init_command(ctx, command, false);
     }
@@ -2684,6 +2689,7 @@ ctl_context_done(struct ctl_context *ctx,
         ctl_context_done_command(ctx, command);
     }
     invalidate_cache(ctx);
+    ds_destroy(&ctx->output);
 }
 
 char * OVS_WARN_UNUSED_RESULT
