@@ -97,7 +97,22 @@ def open_spell_check_dict():
                           'debian', 'travis', 'cirrus', 'appveyor', 'faq',
                           'erspan', 'const', 'hotplug', 'addresssanitizer',
                           'ovsdb', 'dpif', 'veth', 'rhel', 'jsonrpc', 'json',
-                          'syscall', 'lacp', 'ipf', 'skb', 'valgrind']
+                          'syscall', 'lacp', 'ipf', 'skb', 'valgrind',
+                          'appctl', 'arp', 'asan', 'backport', 'backtrace',
+                          'chmod', 'ci', 'cpu', 'cpus', 'dnat', 'dns', 'dpcls',
+                          'eol', 'ethtool', 'fdb', 'freebsd', 'gcc', 'github',
+                          'glibc', 'gre', 'inlined', 'ip', 'ipfix', 'ipsec',
+                          'ixgbe', 'libbpf', 'libcrypto', 'libgcc',
+                          'libopenvswitch', 'libreswan', 'libssl', 'libxdp',
+                          'lldp', 'llvm', 'lockless', 'mcast', 'megaflows',
+                          'mfex', 'ncat', 'networkmanager', 'pcap', 'pedit',
+                          'pidfile', 'pps', 'rculist', 'rebalance', 'rebased'
+                          'recirculations', 'revalidators', 'rst', 'sed',
+                          'shrinked', 'snat', 'stderr', 'stdout', 'testpmd',
+                          'tftp', 'timeval', 'trie', 'tso', 'ubsan', 'ukey',
+                          'umask', 'unassociated', 'unixctl', 'uuid'
+                          'virtqueue', 'vms', 'vnet', 'vport', 'vports',
+                          'vtep', 'wc', 'wget', 'xenserver']
 
         global spell_check_dict
 
@@ -427,7 +442,8 @@ def check_spelling(line, comment):
     if not spell_check_dict or not spellcheck:
         return False
 
-    if line.startswith('Fixes: '):
+    is_name_tag = re.compile(r'^\s*([a-z-]+-by): (.*@.*)$', re.I | re.M | re.S)
+    if line.startswith('Fixes: ') or is_name_tag.match(line):
         return False
 
     words = filter_comments(line, True) if comment else line
@@ -479,7 +495,7 @@ def __check_doc_is_listed(text, doctype, docdir, docfile):
         docre = re.compile(r'\n\+.*{}'.format(docfile.replace('.rst', '')))
     elif doctype == 'automake':
         beginre = re.compile(r'\+\+\+.*Documentation/automake.mk')
-        docre = re.compile(r'\n\+\t{}/{}'.format(docdir, docfile))
+        docre = re.compile(r'\n\+\t(?:{}/)?{}'.format(docdir, docfile))
     else:
         raise NotImplementedError("Invalid doctype: {}".format(doctype))
 
@@ -723,7 +739,7 @@ infix_operators = \
             '&=', '^=', '|=', '<<=', '>>=']] \
     + [r'[^<" ]<[^=" ]',
        r'[^\->" ]>[^=" ]',
-       r'[^ !()/"]\*[^/]',
+       r'[^ !()/"\*]\*+[^/]',
        r'[^ !&()"]&',
        r'[^" +(]\+[^"+;]',
        r'[^" \-(]\-[^"\->;]',
